class Stack:
    def __init__(self):
        self.items = []  # 尾部为栈顶

    def is_empty(self):
        return self.items == []

    def push(self, item):
        self.items.append(item)

    def peek(self):
        return self.items[-1]

    def pop(self):
        return self.items.pop()

    def size(self):
        return len(self.items)


class Queue:
    def __init__(self):
        self.items = []

    def is_empty(self):
        return self.items == []

    def enqueue(self, item):
        self.items.append(item)

    def dequeue(self):
        return self.items.pop(0)

    def size(self):
        return len(self.items)


class Deque:
    def __init_(self):
        self.items = []

    def is_empty(self):
        return self.items == []

    def add_front(self, item):
        self.items.insert(0, item)

    def add_rear(self, item):
        self.items.append(item)

    def remove_front(self):
        return self.item.pop(0)

    def remove_rear(self):
        return self.item.pop()

    def size(self):
        return len(self.items)



from setuptools import setup

setup(
    name='dstwo',
    version='1.0.0',
    author='Reny',
    author_email='Rjs3175@aliyun.com',
    description='Basic data structures and algorithms',
    packages=['data_struct'],
    install_requires=[],
)
